# Changelog

All notable changes to this project will be documented in this file.

The CHANGELOG is powered by [Commitizen](https://commitizen-tools.github.io/commitizen/).

## v1.0.1 (2025-05-29)

### Fix

- version bumping and CHANGELOG keeping tools
- **pyproject**: fix section with deps from uv autogen to supported

## v1.0.0 (2025-05-29)

### Feat

- implement tf2ss conversion and time response functionalities
- add initial project structure with .gitignore, pre-commit configuration, contributing guidelines, license, README, and project metadata
